@@ -59,20 +59,17 @@ class mrg32k3a_engine
 public:
     struct mrg32k3a_state
     {
-        unsigned int g1[3];
-        unsigned int g2[3];
-
     #ifndef ROCRAND_DETAIL_BM_NOT_IN_STATE
         // The Box–Muller transform requires two inputs to convert uniformly
         // distributed real values [0; 1] to normally distributed real values
         // (with mean = 0, and stddev = 1). Often user wants only one
         // normally distributed number, to save performance and random
         // numbers the 2nd value is saved for future requests.
-        unsigned int boxmuller_float_state; // is there a float in boxmuller_float
-        unsigned int boxmuller_double_state; // is there a double in boxmuller_double
-        float boxmuller_float; // normally distributed float
         double boxmuller_double; // normally distributed double
+        float  boxmuller_float; // normally distributed float
     #endif
+        unsigned int g1[3];
+        unsigned int g2[3];
     };
 
     __forceinline__ __device__ __host__ mrg32k3a_engine()
@@ -146,8 +143,8 @@ public:
                                                      const unsigned long long offset)
     {
     #ifndef ROCRAND_DETAIL_BM_NOT_IN_STATE
-        m_state.boxmuller_float_state = 0;
-        m_state.boxmuller_double_state = 0;
+        m_state.boxmuller_float  = ROCRAND_NAN_FLOAT;
+        m_state.boxmuller_double = ROCRAND_NAN_DOUBLE;
     #endif
         this->discard_subsequence_impl(subsequence);
         this->discard_impl(offset);
